MAPIOutParam

Struct MAPIOutParam 

pub struct MAPIOutParam<T>(/* private fields */)
where
    T: Sized;
Hold an out-pointer for MAPI APIs which perform their own buffer allocations. This version does not perform any validation of the buffer size, so the typed accessors are inherently unsafe.

Implementations

Source

impl<T> MAPIOutParam<T>
where T: Sized,

pub fn as_mut_ptr(&mut self) -> *mut *mut T

Get a *mut *mut T suitable for use with a MAPI API that fills in an out-pointer with a newly allocated buffer.

pub unsafe fn as_mut(&mut self) -> Option<&mut T>

Access a single element of type T.

Safety

This version does not perform any validation of the buffer size, so the typed accessors are inherently unsafe. The only thing it handles is a null check.

pub unsafe fn as_mut_slice(&mut self, count: usize) -> Option<&mut [T]>

Access a slice with count elements of type T.

Safety

This version does not perform any validation of the buffer size, so the typed accessors are inherently unsafe. The only thing it handles is a null check.